Module: Auchandirect::ScrAPI::Items

Defined in:
lib/auchandirect/scrAPI/items.rb

Overview

Storexplore api definition to browse all the items available at auchandirect.com See

The store has 3 depths of categories. The only attribute the categories have is their name The items are all child of the bottom categories, here are their attributes

  • brand

  • name

  • price

  • image (url of the link to the image)

  • remote_id (the id of this item in the auchandirect database)

Constant Summary collapse

NAMES_SEPARATOR =
', '